@@ -94,11 +94,9 @@ DAISIE_format_GW <- function(island_replicates,
 
       several_islands[[rep]] <- island_list
       if (verbose == TRUE) {
-        print(paste("Island being formatted: ",
-                    rep,
-                    "/",
-                    length(island_replicates),
-                    sep = ""))
+        message(
+          "Island being formatted: ", rep, "/", length(island_replicates)
+        )
       }
     }
   return(several_islands)
