@@ -1,5 +1,5 @@
 test_that("use", {
-  expect_silent(DAISIE_ExpEIN(
+  testthat::expect_silent(DAISIE_ExpEIN(
     t = 4,
     pars = c(0.5, 0.1, Inf, 0.01, 0.4),
     M = 1000
@@ -12,13 +12,13 @@ test_that("output is named list of length 3", {
     pars = c(0.5, 0.1, Inf, 0.01, 0.4),
     M = 1000
   )
-  expect_true(
+  testthat::expect_true(
     is.list(ExpEIN_out)
   )
-  expect_length(
+  testthat::expect_length(
     ExpEIN_out, 3
   )
-  expect_equal(
+  testthat::expect_equal(
     names(ExpEIN_out), c("ExpE", "ExpI", "ExpN")
   )
 })
@@ -29,13 +29,13 @@ test_that("use with type2", {
     pars = c(0.5, 0.1, Inf, 0.01, 0.4, 0.7, 0.2, Inf, 0.05, 0.1, 0.1),
     M = 1000
   )
-  expect_true(
+  testthat::expect_true(
     is.list(ExpEIN_out)
   )
-  expect_length(
+  testthat::expect_length(
     ExpEIN_out, 3
   )
-  expect_equal(
+  testthat::expect_equal(
     names(ExpEIN_out), c("ExpE", "ExpI", "ExpN")
   )
 })
@@ -46,13 +46,13 @@ test_that("use with t == Inf", {
     pars = c(0.5, 0.1, Inf, 0.01, 0.4),
     M = 1000
   )
-  expect_true(
+  testthat::expect_true(
     is.list(ExpEIN_out)
   )
-  expect_length(
+  testthat::expect_length(
     ExpEIN_out, 3
   )
-  expect_equal(
+  testthat::expect_equal(
     names(ExpEIN_out), c("ExpE", "ExpI", "ExpN")
   )
 })
@@ -60,7 +60,7 @@ test_that("use with t == Inf", {
 
 
 test_that("abuse", {
-  expect_error(DAISIE_ExpEIN(
+  testthat::expect_error(DAISIE_ExpEIN(
     t = 4,
     pars = "nonsense",
     M = 1000
