@@ -14,7 +14,7 @@ test_that("DAISIE_ML4 is silent and produces correct output", {
                                    relaxed_par = "extinction",
                                    par_sd = 0.1,
                                    par_upper_bound = 1))
-  expect_equal(2, 2)
+  testthat::expect_equal(2, 2)
 })
 
 test_that("DAISIE_loglik_all_choosepar4 is silent and produces correct output", {
@@ -39,5 +39,5 @@ test_that("DAISIE_loglik_all_choosepar4 is silent and produces correct output",
       abstolint = 1e-16,
       reltolint = 1e-10
     ))))
-  expect_equal(output, -77.50300643925)
+  testthat::expect_equal(output, -77.50300643925)
 })
