@@ -10,7 +10,7 @@ test_that("Clean run should be silent", {
   ana_rate <- 1.0
 
   testthat::expect_silent(
-    DAISIE:::DAISIE_sim_core_cr(
+    DAISIE_sim_core_cr(
       time = sim_time,
       mainland_n = n_mainland_species,
       pars = c(clado_rate, ext_rate, carr_cap, imm_rate, ana_rate),
@@ -32,7 +32,7 @@ test_that("Clean run should be silent", {
 
 test_that("Ontogeny simulation should run silent", {
   set.seed(234567890)
-  testthat::expect_silent(DAISIE:::DAISIE_sim_core_time_dep(
+  testthat::expect_silent(DAISIE_sim_core_time_dep(
     time = 10,
     mainland_n = 1000,
     pars = c(0.0001, 2.2, 0.005, 0.001, 1),
