@@ -37,7 +37,7 @@ test_that("loglik macaronesia 2 type works", {
                                          Macaronesia_datalist[[i]],
                                          methode = "lsodes")
   }
-  expect_equal(loglik, -449.921430187808)
+  testthat::expect_equal(loglik, -449.921430187808)
 })
 
 test_that("clade specific rate-shift loglik works", {
@@ -57,7 +57,7 @@ test_that("clade specific rate-shift loglik works", {
     datalist = Galapagos_datalist,
     methode = "ode45",
     CS_version = 1)
-  expect_equal(SR_loglik_CS, loglik_CS)
+  testthat::expect_equal(SR_loglik_CS, loglik_CS)
 })
 
 test_that("IW and CS loglik is same when K = Inf", {
@@ -88,7 +88,6 @@ test_that("IW and CS loglik is same when K = Inf", {
     methode = "odeint::runge_kutta_fehlberg78"
   )
 
-
   loglik_CS <- DAISIE_loglik_CS(
     pars1 = pars1,
     pars2 = pars2,
@@ -97,8 +96,8 @@ test_that("IW and CS loglik is same when K = Inf", {
     CS_version = 1
   )
 
-  expect_equal(loglik_IW, loglik_IW2, tol = 5E-6)
-  expect_equal(loglik_IW, loglik_CS, tol = 5E-6)
+  testthat::expect_equal(loglik_IW, loglik_IW2, tol = 5E-6)
+  testthat::expect_equal(loglik_IW, loglik_CS, tol = 5E-6)
 })
 
 test_that("DAISIE_ML simple case works", {
@@ -127,7 +126,7 @@ test_that("DAISIE_ML simple case works", {
       idparsfix = NULL
     )
   ))
-  expect_equal(expected_mle, tested_mle)
+  testthat::expect_equal(expected_mle, tested_mle)
 })
 
 test_that("DAISIE_ML simple case works with zero probability of initial presence", {
@@ -147,79 +146,122 @@ test_that("DAISIE_ML simple case works with zero probability of initial presence
   )
   utils::data(Galapagos_datalist)
 
-  invisible(capture.output(
     tested_mle <- DAISIE_ML(
       datalist = Galapagos_datalist,
       initparsopt = c(2.5, 2.7, 20, 0.009, 1.01),
       ddmodel = 11,
       idparsopt = 1:5,
       parsfix = 0,
-      idparsfix = 6
+      idparsfix = 6,
+      verbose = 0
     )
-  ))
-  expect_equal(expected_mle, tested_mle)
-})
-
-test_that("DAISIE_ML simple case works with nonzero probability of initial presence", {
-  skip_if(Sys.getenv("CI") == "" && !(Sys.getenv("USERNAME") == "rampa"),
-          message = "Run only on CI")
-  expected_mle <- data.frame(
-    lambda_c = 2.58373135630384,
-    mu = 2.70882802751483,
-    K = 2992.20770192179,
-    gamma = 0.00937711049761019,
-    lambda_a = 0.999324695828027,
-    prob_init_pres = 0.1,
-    loglik = -75.9926628720867,
-    df = 5L,
-    conv = 0L
-  )
-  utils::data(Galapagos_datalist)
-
-  invisible(capture.output(
-    tested_mle <- DAISIE_ML(
+    expected_calculated_mle <- DAISIE_ML(
       datalist = Galapagos_datalist,
       initparsopt = c(2.5, 2.7, 20, 0.009, 1.01),
       ddmodel = 11,
       idparsopt = 1:5,
-      parsfix = 0.1,
-      idparsfix = 6
+      parsfix = NULL,
+      idparsfix = NULL,
+      verbose = 0
     )
-  ))
-  expect_equal(expected_mle, tested_mle)
+
+  testthat::expect_equal(expected_mle, tested_mle)
+  # Results match if prob_init_pres is removed
+  testthat::expect_equal(expected_calculated_mle, tested_mle[-6])
+})
+
+test_that("DAISIE_ML simple case works with nonzero probability of initial
+          presence", {
+            skip_if(Sys.getenv("CI") == "" && !(Sys.getenv("USERNAME") == "rampa"),
+                    message = "Run only on CI")
+            expected_mle <- data.frame(
+              lambda_c = 3.30567366427796,
+              mu = 3.86584745010284,
+              K = Inf,
+              gamma = 0.0144177568387567,
+              lambda_a = 0.699608034134341,
+              prob_init_pres = 0.1,
+              loglik = -78.9245109502749,
+              df = 5L,
+              conv = 0L
+            )
+            utils::data(Galapagos_datalist)
+
+            tested_mle <- DAISIE_ML(
+              datalist = Galapagos_datalist,
+              initparsopt = c(2.5, 2.7, 20, 0.009, 1.01),
+              ddmodel = 11,
+              idparsopt = 1:5,
+              parsfix = 0.1,
+              idparsfix = 6,
+              verbose = 0
+              # verbose = 3,
+            )
+            testthat::expect_equal(expected_mle, tested_mle, tolerance = 2E-3)
+            # tolerance due to different OS results between windows, macOS and
+            # ubuntu added in #162
+          })
+
+
+test_that("DAISIE_ML with nonzero probability of initial presence gives
+          different results from DAISIE_ML with 0 probability of initial
+          presence", {
+  skip_if(Sys.getenv("CI") == "" && !(Sys.getenv("USERNAME") == "rampa"),
+          message = "Run only on CI")
+  utils::data(Galapagos_datalist)
+
+  tested_mle_zero <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 2.7, 20, 0.009, 1.01),
+    ddmodel = 11,
+    idparsopt = 1:5,
+    parsfix = 0,
+    idparsfix = 6,
+    verbose = 0
+  )
+  tested_mle_nonzero <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 2.7, 20, 0.009, 1.01),
+    ddmodel = 11,
+    idparsopt = 1:5,
+    parsfix = 0.1,
+    idparsfix = 6,
+    verbose = 0
+  )
+  testthat::expect_false(isTRUE(all.equal(tested_mle_zero, tested_mle_nonzero)))
 })
 
 test_that("DAISIE_ML simple case works with estimating probability of initial
           presence", {
-  skip_if(Sys.getenv("CI") == "" && !(Sys.getenv("USERNAME") == "rampa"),
-          message = "Run only on CI")
-  skip_on_cran()
+            skip_if(Sys.getenv("CI") == "" && !(Sys.getenv("USERNAME") == "rampa"),
+                    message = "Run only on CI")
+            skip_on_cran()
 
-  expected_mle <- data.frame(
-    lambda_c = 2.54079308283855,
-    mu = 2.66563367593515,
-    K = 6249.71023359369,
-    gamma = 0.00919247416324124,
-    lambda_a = 1.01076206116211,
-    prob_init_pres = 9.45796543536632e-06,
-    loglik = -75.9935681347126,
-    df = 6L,
-    conv = 0L
-  )
+            expected_mle <- data.frame(
+              lambda_c = 2.54079308283855,
+              mu = 2.66563367593515,
+              K = 6249.71023359369,
+              gamma = 0.00919247416324124,
+              lambda_a = 1.01076206116211,
+              prob_init_pres = 9.45796543536632e-06,
+              loglik = -75.9935681347126,
+              df = 6L,
+              conv = 0L
+            )
 
-  utils::data(Galapagos_datalist)
-  invisible(capture.output(
-    tested_mle <- DAISIE_ML(
-      datalist = Galapagos_datalist,
-      initparsopt = c(2.5, 2.7, 20, 0.009, 1.01, 0.001),
-      ddmodel = 11,
-      idparsopt = 1:6,
-      parsfix = NULL,
-      idparsfix = NULL
-    )
-  ))
-  expect_equal(tested_mle, expected_mle)
-})
+            utils::data(Galapagos_datalist)
+            invisible(capture.output(
+              tested_mle <- DAISIE_ML(
+                datalist = Galapagos_datalist,
+                initparsopt = c(2.5, 2.7, 20, 0.009, 1.01, 0.001),
+                ddmodel = 11,
+                idparsopt = 1:6,
+                parsfix = NULL,
+                idparsfix = NULL
+              )
+            ))
+            testthat::expect_equal(tested_mle, expected_mle)
+          })
 
 test_that("The parameter choice for 2type DAISIE_ML works", {
   Galapagos_datalist_2types <- NULL
@@ -241,7 +283,7 @@ test_that("The parameter choice for 2type DAISIE_ML works", {
       maxiter = 30
     )
   ))
-  expect_equal(fit$loglik, -74.7557, tol = 1E-3)
+  testthat::expect_equal(fit$loglik, -74.7557, tol = 1E-3)
 })
 
 test_that("conditioning works", {
@@ -309,7 +351,7 @@ test_that("conditioning works", {
     pars2_2type_cond0,
     Galapagos_datalist_2types
   )
-  expect_equal(loglik_CS_2type_cond0, -61.7028188767349)
+  testthat::expect_equal(loglik_CS_2type_cond0, -61.7028188767349)
 
   # Cond 1
   ## 1 type
@@ -323,7 +365,7 @@ test_that("conditioning works", {
     methode = 'ode45',
     CS_version = 1
   )
-  expect_equal(loglik_CS_1type_cond1, -96.45757823017264)
+  testthat::expect_equal(loglik_CS_1type_cond1, -96.45757823017264)
 
   ## 2 type
   data(Galapagos_datalist_2types, package = "DAISIE")
@@ -346,7 +388,7 @@ test_that("conditioning works", {
     pars2_2type_cond1,
     Galapagos_datalist_2types
   )
-  expect_equal(loglik_CS_2type_cond1, -61.4375954386635)
+  testthat::expect_equal(loglik_CS_2type_cond1, -61.4375954386635)
 
   # Cond 5
   ## 1 type
@@ -360,7 +402,7 @@ test_that("conditioning works", {
     methode = 'ode45',
     CS_version = 1
   )
-  expect_equal(loglik_CS_1type_cond5, -95.14000237210625)
+  testthat::expect_equal(loglik_CS_1type_cond5, -95.14000237210625)
 
   ## 2 type
   data(Galapagos_datalist_2types, package = "DAISIE")
@@ -383,5 +425,89 @@ test_that("conditioning works", {
     pars2_2type_cond5,
     Galapagos_datalist_2types
   )
-  expect_equal(loglik_CS_2type_cond5, -61.3735194058527)
+  testthat::expect_equal(loglik_CS_2type_cond5, -61.3735194058527)
+})
+
+test_that("ML with fixed parameters should be different from free parameters
+          and be nonzero", {
+  skip_if(Sys.getenv("CI") == "" && !(Sys.getenv("USERNAME") == "rampa"),
+          message = "Run only on CI")
+  skip_on_cran()
+  utils::data(Galapagos_datalist)
+
+  tested_mle_free <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 2.7, 20, 0.009, 1.01),
+    ddmodel = 11,
+    idparsopt = 1:5,
+    parsfix = NULL,
+    idparsfix = NULL,
+    tol = c(1e-2, 1e-3, 1e-4),
+    verbose = 0
+  )
+  tested_mle_fix_clado <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.7, 20, 0.009, 1.01),
+    ddmodel = 11,
+    idparsopt = 2:5,
+    parsfix = 2.5,
+    idparsfix = 1,
+    tol = c(1e-2, 1e-3, 1e-4),
+    verbose = 0
+  )
+  tested_mle_fix_mu <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 20, 0.009, 1.01),
+    ddmodel = 11,
+    idparsopt = c(1, 3:5),
+    parsfix = 2.7,
+    idparsfix = 2,
+    tol = c(1e-2, 1e-3, 1e-4),
+    verbose = 0
+  )
+  tested_mle_fix_k <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 2.7, 0.009, 1.01),
+    ddmodel = 11,
+    idparsopt = c(1, 2, 4, 5),
+    parsfix = 20,
+    idparsfix = 3,
+    tol = c(1e-2, 1e-3, 1e-4),
+    verbose = 0
+  )
+  tested_mle_fix_immig <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 2.7, 20, 1.01),
+    ddmodel = 11,
+    idparsopt = c(1:3, 5),
+    parsfix = 0.009,
+    idparsfix = 4,
+    tol = c(1e-2, 1e-3, 1e-4),
+    verbose = 0
+  )
+  tested_mle_fix_ana <- DAISIE_ML(
+    datalist = Galapagos_datalist,
+    initparsopt = c(2.5, 2.7, 20, 0.009),
+    ddmodel = 11,
+    idparsopt = 1:4,
+    parsfix = 1.01,
+    idparsfix = 5,
+    tol = c(1e-2, 1e-3, 1e-4),
+    verbose = 0
+  )
+
+  # Fixing one parameter should not return the same as a leaving all free
+  testthat::expect_false(isTRUE(all.equal(tested_mle_free, tested_mle_fix_clado)))
+  testthat::expect_false(isTRUE(all.equal(tested_mle_free, tested_mle_fix_mu)))
+  testthat::expect_false(isTRUE(all.equal(tested_mle_free, tested_mle_fix_k)))
+  testthat::expect_false(isTRUE(all.equal(tested_mle_free, tested_mle_fix_immig)))
+  testthat::expect_false(isTRUE(all.equal(tested_mle_free, tested_mle_fix_ana)))
+
+
+  # Fixing one parameter should not return pars as 0, unless set to it
+  testthat::expect_false(0 %in% tested_mle_fix_clado[1:5])
+  testthat::expect_false(0 %in% tested_mle_fix_mu[1:5])
+  testthat::expect_false(0 %in% tested_mle_fix_k[1:5])
+  testthat::expect_false(0 %in% tested_mle_fix_immig[1:5])
+  testthat::expect_false(0 %in% tested_mle_fix_ana[1:5])
 })
